netapp_ontap.models.cifs_service_options API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cifs_service_options`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CifsServiceOptionsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsServiceOptions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `admin_to_root_mapping: bool GET POST PATCH`

    Specifies whether or not Administrator can be mapped to the UNIX user "root".

  `advanced_sparse_file: bool GET POST PATCH`

    Specifies whether or not the CIFS server supports the advanced sparse file capabilities. This allows CIFS clients to query the allocated ranges of a file and to write zeroes or free data blocks for ranges of a file.

  `backup_symlink_enabled: bool GET POST PATCH`

    Specifies whether or not to preserve UNIX symlinks during backup through SMB.

  `client_dup_detection_enabled: bool GET POST PATCH`

    Specifies whether or not client duplicate session detection is enabled for CIFS.

  `client_version_reporting_enabled: bool GET POST PATCH`

    Specifies whether or not client version reporting is enabled for CIFS.

  `copy_offload: bool GET POST PATCH`

    Specifies whether or not to enable the Copy Offload feature. This feature enables direct data transfers within or between compatible storage devices without transferring the data through the host computer.
    Note that this will also enable/disable the direct copy feature accordingly.

  `dac_enabled: bool GET POST PATCH`

    Specifies whether or not the Dynamic Access Control (DAC) feature is enabled for the CIFS server.

  `export_policy_enabled: bool GET POST PATCH`

    Specifies whether or not export policies are enabled for CIFS.

  `fake_open: bool GET POST PATCH`

    Specifies whether or not fake open support is enabled. This parameter allows you to optimize the open and close requests coming from SMB 2 clients.

  `fsctl_trim: bool GET POST PATCH`

    Specifies whether or not the trim requests (FSCTL_FILE_LEVEL_TRIM) are supported on the CIFS server.

  `junction_reparse: bool GET POST PATCH`

    Specifies whether or not the reparse point support is enabled. When enabled the CIFS server exposes junction points to Windows clients as reparse points. This parameter is only active if the client has negotiated use of the SMB 2 or SMB 3 protocol. This parameter is not supported for SVMs with Infinite Volume.

  `large_mtu: bool GET POST PATCH`

    Specifies whether or not SMB clients can send reads up to 1 MB in size.

  `max_connections_per_session: Size GET POST PATCH`

    Specifies the maximum number of connections allowed per multichannel session.

    Example: 32

  `max_lifs_per_session: Size GET POST PATCH`

    Specifies the maximum number of LIFs advertised per multichannel session.

    Example: 256

  `max_opens_same_file_per_tree: Size GET POST PATCH`

    Specifies the maximum number of opens on the same file per tree.

    Example: 1000

  `max_same_tree_connect_per_session: Size GET POST PATCH`

    Specifies the maximum number of same tree connections per session.

    Example: 5000

  `max_same_user_sessions_per_connection: Size GET POST PATCH`

    Specifies the maximum number of same user sessions per connection.

    Example: 2500

  `max_watches_set_per_tree: Size GET POST PATCH`

    Specifies the maximum number of watches set per tree.

    Example: 500

  `multichannel: bool GET POST PATCH`

    Specifies whether or not the CIFS server supports Multichannel.

  `null_user_windows_name: str GET POST PATCH`

    Specifies a Windows User or Group name that should be mapped in case of a NULL user value.

  `path_component_cache: bool GET POST PATCH`

    Specifies whether or not the path component cache is enabled on the CIFS server.

  `referral: bool GET POST PATCH`

    Specifies whether or not to refer clients to more optimal LIFs. When enabled, it automatically refers clients to a data LIF local to the node which hosts the root of the requested share.

  `shadowcopy: bool GET POST PATCH`

    Specifies whether or not to enable the Shadowcopy Feature. This feature enables to take share-based backup copies of data that is in a data-consistent state at a specific point in time where the data is accessed over SMB 3.0 shares.

  `shadowcopy_dir_depth: Size GET POST PATCH`

    Specifies the maximum level of subdirectories on which ONTAP should create shadow copies.

  `smb_credits: Size GET POST PATCH`

    Specifies the maximum number of outstanding requests on a CIFS connection.

    Example: 128

  `trusted_domain_enum_search_enabled: bool GET POST PATCH`

    Specifies whether or not to enable trusted domain search. - If this parameter is set to true, it displays CIFS options only for CIFS servers that support enumeration of bidirectional trusted domains and that support searching in all bidirectional trusted domains when performing Windows user lookups for UNIX user to Windows user name mapping. - If set to false, it displays CIFS options for CIFS servers that do not support enumeration of bidirectional trusted domains.

  `widelink_reparse_versions: List[str] GET POST PATCH`

    Specifies the CIFS protocol versions for which the widelink is reported as reparse point.